<?php
/**
 * This file contains functions and hooks for styling Hootkit plugin
 *   Hootkit is a free plugin released under GPL license and hosted on wordpress.org.
 *   It is recommended to the user via wp-admin using TGMPA class
 *
 * This file is loaded at 'after_setup_theme' action @priority 10 ONLY IF hootkit plugin is active
 *
 * @package    Unos Publisher
 * @subpackage HootKit
 */

// Add dynamic CSS for hootkit
add_action( 'hoot_dynamic_cssrules', 'unospub_hootkit_dynamic_cssrules', 8 );

add_action( 'wp_enqueue_scripts', 'unospub_enqueue_hootkit', 15 );
if ( !function_exists( 'unospub_enqueue_hootkit' ) ) :
function unospub_enqueue_hootkit() {

	// Backward compatibility @deprecated <Unos2.9.16
	if ( !function_exists( 'unos_enqueue_childhootkit' ) ) {
	/* 'unos-hootkit' is loaded using 'hoot_locate_style' which loads child theme location. Hence deregister it and load files again */
	wp_deregister_style( 'unos-hootkit' );
	/* Load Hootkit Style - Add dependency so that hotkit is loaded after */
	if ( file_exists( hoot_data()->template_dir . 'hootkit/hootkit.css' ) )
	wp_enqueue_style( 'unos-hootkit', hoot_data()->template_uri . 'hootkit/hootkit.css', array( 'hoot-style' ), hoot_data()->template_version );
	if ( file_exists( hoot_data()->child_dir . 'hootkit/hootkit.css' ) )
	wp_enqueue_style( 'unospub-hootkit', hoot_data()->child_uri . 'hootkit/hootkit.css', array( 'hoot-style', 'unos-hootkit' ), hoot_data()->childtheme_version );
	}

}
endif;

add_filter( 'hoot_style_builder_inline_style_handle', 'unospub_dynamic_css_hootkit_handle', 8 );
if ( !function_exists( 'unospub_dynamic_css_hootkit_handle' ) ) :
function unospub_dynamic_css_hootkit_handle( $handle ) {
	// Backward compatibility @deprecated <Unos2.9.16
	if ( !function_exists( 'unos_dynamic_css_childhootkit_handle' ) )
	return 'unospub-hootkit';
	else return $handle;
}
endif;

/**
 * Custom CSS built from user theme options for hootkit features
 *
 * @since 1.0
 * @access public
 */
if ( !function_exists( 'unospub_hootkit_dynamic_cssrules' ) ) :
function unospub_hootkit_dynamic_cssrules() {

	global $hoot_style_builder;

	// Get user based style values
	$styles = unos_user_style();
	extract( $styles );

	/*** Add Dynamic CSS ***/

	hoot_add_css_rule( array(
						'selector'  => '.social-icons-icon',
						'property'  => array(
							// property  => array( value, idtag, important, typography_reset ),
							'background' => array( $accent_font, 'accent_font' ),
							'border-color' => array( $accent_color, 'accent_color' ),
							),
					) );
	hoot_add_css_rule( array(
						'selector'  => '#topbar .social-icons-icon, #page-wrapper .social-icons-icon',
						'property'  => array(
							// property  => array( value, idtag, important, typography_reset ),
							'color'      => array( $accent_color, 'accent_color' ),
							),
					) );

}
endif;

/**
 * Modify Post Grid default style
 *
 * @since 1.0
 * @param array $settings
 * @return string
 */
function unospub_post_grid_widget_settings( $settings ) {
	if ( isset( $settings['form_options']['unitheight']['desc'] ) )
		$settings['form_options']['unitheight']['desc'] = __( 'Default: 240 (in pixels)', 'unos-publisher' );
	return $settings;
}
add_filter( 'hootkit_post_grid_widget_settings', 'unospub_post_grid_widget_settings', 5 );
add_filter( 'hootkit_content_grid_widget_settings', 'unospub_post_grid_widget_settings', 5 );